.. list-table:: Variables from GFS available in ufs2arco
   :widths: 18 50 12
   :header-rows: 1

   * - Variable
     - Long Name
     - Forecast Only
   * - ``SUNSD``
     - Sunshine Duration
     - False
   * - ``accum_acpcp``
     - Convective precipitation (water) accumulated over forecast
     - True
   * - ``accum_tp``
     - Total Precipitation accumulated over forecast
     - True
   * - ``accum_watr``
     - Water runoff accumulated over forecast
     - True
   * - ``aptmp2``
     - 2 metre Apparent temperature
     - False
   * - ``avg_al``
     - Time-mean forecast albedo
     - True
   * - ``avg_cduvb``
     - Time-mean Clear sky UV-B downward solar flux
     - True
   * - ``avg_cfrzr``
     - Time-mean Categorical freezing rain
     - True
   * - ``avg_cicep``
     - Time-mean Categorical ice pellets
     - True
   * - ``avg_cpr``
     - Time-mean Convective precipitation rate
     - True
   * - ``avg_crain``
     - Time-mean Categorical rain
     - True
   * - ``avg_csnow``
     - Time-mean Categorical snow
     - True
   * - ``avg_duvb``
     - Time-mean UV-B downward solar flux
     - True
   * - ``avg_gflux``
     - Time-mean Ground heat flux
     - True
   * - ``avg_iegwss``
     - Time-mean Instantaneous eastward gravity wave surface stress
     - True
   * - ``avg_ingwss``
     - Time-mean Instantaneous northward gravity wave surface stress
     - True
   * - ``avg_ishf``
     - Time-mean surface sensible heat flux
     - True
   * - ``avg_prate``
     - Time-mean Precipitation rate
     - True
   * - ``avg_sdlwrf``
     - Time-mean Surface downward long-wave radiation flux
     - True
   * - ``avg_sdswrf``
     - Time-mean Surface downward short-wave radiation flux
     - True
   * - ``avg_slhtf``
     - Time-mean surface latent heat flux
     - True
   * - ``avg_sulwrf``
     - Time-mean Surface upward long-wave radiation flux
     - True
   * - ``avg_suswrf``
     - Time-mean Surface upward short-wave radiation flux
     - True
   * - ``avg_utaua``
     - Time-mean U-component of atmospheric surface momentum flux
     - True
   * - ``avg_vtaua``
     - Time-mean V-component of atmospheric surface momentum flux
     - True
   * - ``cape``
     - Convective available potential energy
     - False
   * - ``cin``
     - Convective inhibition
     - False
   * - ``cnwat``
     - Plant canopy surface water
     - False
   * - ``cpofp``
     - Percent frozen precipitation
     - False
   * - ``d2m``
     - 2 metre dewpoint temperature
     - False
   * - ``fldcp``
     - Field Capacity
     - False
   * - ``gh``
     - Geopotential height
     - False
   * - ``gust``
     - Wind speed (gust)
     - False
   * - ``hindex``
     - Haines Index
     - False
   * - ``lftx``
     - Surface lifted index
     - False
   * - ``lftx4``
     - Best (4-layer) lifted index
     - False
   * - ``lsm``
     - Land-sea mask
     - False
   * - ``mslet``
     - MSLP (Eta model reduction)
     - False
   * - ``orog``
     - Orography
     - False
   * - ``pres80``
     - 80 metre Pressure
     - False
   * - ``prmsl``
     - Pressure reduced to MSL
     - False
   * - ``q``
     - Specific humidity
     - False
   * - ``q80``
     - 80 metre Specific humidity
     - False
   * - ``r2``
     - 2 metre relative humidity
     - False
   * - ``sde``
     - Snow depth
     - False
   * - ``sdwe``
     - Water equivalent of accumulated snow depth (deprecated)
     - False
   * - ``sh2``
     - 2 metre specific humidity
     - False
   * - ``siconc``
     - Sea ice area fraction
     - False
   * - ``sithick``
     - Sea ice thickness
     - False
   * - ``sp``
     - Surface pressure
     - False
   * - ``t``
     - Temperature
     - False
   * - ``t100``
     - 100 metre Temperature
     - False
   * - ``t2m``
     - 2 metre temperature
     - False
   * - ``t80``
     - 80 metre Temperature
     - False
   * - ``t_surface``
     - Temperature at surface
     - False
   * - ``tmax2``
     - 2 metre Maximum temperature
     - True
   * - ``tmin2``
     - 2 metre Minimum temperature
     - True
   * - ``u``
     - U component of wind
     - False
   * - ``u10``
     - 10 metre U wind component
     - False
   * - ``u100``
     - 100 metre U wind component
     - False
   * - ``u80``
     - 80 metre U component of wind
     - False
   * - ``v``
     - V component of wind
     - False
   * - ``v10``
     - 10 metre V wind component
     - False
   * - ``v100``
     - 100 metre V wind component
     - False
   * - ``v80``
     - 80 metre V component of wind
     - False
   * - ``w``
     - Vertical velocity
     - False
   * - ``wilt``
     - Wilting Point
     - False
